------
--Definitions
------

--Setup keybinding strings for bindings.xml
_G["BINDING_HEADER_STRUDELSTORE"] = "StrudelStore"
_G["BINDING_NAME_STRUDELSTORE_OPEN_SHOW"] = "Open/close StrudelStore window"

--Load addon and libraries
local addonName = ...
_G[addonName] = LibStub("AceAddon-3.0"):NewAddon(addonName, "AceEvent-3.0","AceConsole-3.0");

local addon = _G[addonName];
addon.isRunningMainline = (WOW_PROJECT_ID == WOW_PROJECT_MAINLINE)
addon.isRunningClassicEra = (WOW_PROJECT_ID == WOW_PROJECT_CLASSIC)
addon.isRunningWrath = (WOW_PROJECT_ID == WOW_PROJECT_WRATH_CLASSIC)

addon.config = LibStub("AceConfig-3.0");
addon.helpers = {}
addon.gui = {}
addon.spells = {}

--Default database values
local AddonDB_Defaults = {
  char = {
	startupshow = true,
	minimap = {
		hide = false,
	},
	display = {
		spellOffsetX = 2,
		spellOffsetY = 2,
		maxInRow = 5,
		collapseAnchor = "TOPRIGHT",
	}
  },
}

if addon.isRunningMainline then
	AddonDB_Defaults.char.display.selectedTab = 2;
else
	AddonDB_Defaults.char.display.selectedTab = 1;
end

--------
--Initialization
--------

--Initializing the Addon
function addon:OnInitialize()
	--Register post initialize events
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
	self:RegisterEvent("BAG_UPDATE", function(eventName) self:HandleSpellEvents(eventName) end);
	self:RegisterEvent("UNIT_POWER_UPDATE", function(eventName, unitTarget)
		if unitTarget == "player" then
			self:HandleSpellEvents(eventName)
		end
	end);
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED", function(eventName, unitTarget)
		if unitTarget == "player" then
			self:HandleSpellEvents(eventName)
		end
	end);

	--Setup db and config
	self.db = LibStub("AceDB-3.0"):New(addonName .. "DB", AddonDB_Defaults)
	self.config:SetupConfig();

	--Print welcome message
	local L = LibStub("AceLocale-3.0"):GetLocale(addonName, true);
	self:Print("|cFF99CCFF [StrudelStore] |r" .. L["WelcomeMessage"]);

	self:IntializeFrames();
end

--Intialize the frames of the addon
function addon:IntializeFrames()
	--Create gui
	self.gui:BuildGui();

	if self.db.char.startupshow then
		self.gui.mainframe:Show();
		self.gui.mainCollapsedBtn:Hide();
	else
		self.gui.mainframe:Hide();
		self.gui.mainCollapsedBtn:Show();
	end
end

function addon:PLAYER_ENTERING_WORLD()
	--These parts need to be called here to make sure faction and spell data is available

	--Initialize the spell tables based on faction
	self.spells.InitializeSpellTables();
	--Populate the tabs with spells
	self.gui:PopulateTabs();

	--This only needs to be called and set up once per addon load, so unregister this event here.
	self:UnregisterEvent("PLAYER_ENTERING_WORLD");
end

function addon:HandleSpellEvents(eventName)
	self.gui:UpdateAllTabs();
end